@@ -78,9 +78,10 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
     hook_name : str
         hook name to bind to, e.g. 'client-attached'
     """
-    cmd = ["set-hook", "-t", session.id, hook_name]
+    assert session.id is not None
+    cmd: t.List[str] = ["set-hook", "-t", str(session.id), hook_name]
     hook_cmd = []
-    attached_window = session.attached_window
+    active_window = session.active_window
     for window in session.windows:
         # unfortunately, select-layout won't work unless
         # we've literally selected the window at least once
@@ -92,7 +93,7 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
 
     # unset the hook immediately after executing
     hook_cmd.append(f"set-hook -u -t {session.id} {hook_name}")
-    hook_cmd.append(f"selectw -t {attached_window.id}")
+    hook_cmd.append(f"selectw -t {active_window.id}")
 
     # join the hook's commands with semicolons
     _hook_cmd = "{}".format("; ".join(hook_cmd))
@@ -117,7 +118,7 @@ def load_plugins(session_config: t.Dict[str, t.Any]) -> t.List[t.Any]:
                 tmuxp_echo(
                     style("[Plugin Error] ", fg="red")
                     + f"Couldn't load {plugin}\n"
-                    + style(f"{error}", fg="yellow")
+                    + style(f"{error}", fg="yellow"),
                 )
                 sys.exit(1)
 
@@ -137,14 +138,14 @@ def load_plugins(session_config: t.Dict[str, t.Any]) -> t.List[t.Any]:
                 ):
                     tmuxp_echo(
                         style("[Not Skipping] ", fg="yellow")
-                        + "Plugin versions constraint not met. Exiting..."
+                        + "Plugin versions constraint not met. Exiting...",
                     )
                     sys.exit(1)
             except Exception as error:
                 tmuxp_echo(
                     style("[Plugin Error] ", fg="red")
                     + f"Couldn't load {plugin}\n"
-                    + style(f"{error}", fg="yellow")
+                    + style(f"{error}", fg="yellow"),
                 )
                 sys.exit(1)
 
@@ -373,7 +374,7 @@ def load_workspace(
 
     tmuxp_echo(
         style("[Loading] ", fg="green")
-        + style(str(workspace_file), fg="blue", bold=True)
+        + style(str(workspace_file), fg="blue", bold=True),
     )
 
     # ConfigReader allows us to open a yaml or json file as a dict
@@ -381,7 +382,8 @@ def load_workspace(
 
     # shapes workspaces relative to config / profile file location
     expanded_workspace = loader.expand(
-        raw_workspace, cwd=os.path.dirname(workspace_file)
+        raw_workspace,
+        cwd=os.path.dirname(workspace_file),
     )
 
     # Overridden session name
@@ -473,7 +475,7 @@ def load_workspace(
 
         if choice == "k":
             if builder.session is not None:
-                builder.session.kill_session()
+                builder.session.kill()
                 tmuxp_echo("Session killed.")
         elif choice == "a":
             _reattach(builder)
@@ -636,7 +638,8 @@ def command_load(
 
     for idx, workspace_file in enumerate(args.workspace_files):
         workspace_file = find_workspace_file(
-            workspace_file, workspace_dir=get_workspace_dir()
+            workspace_file,
+            workspace_dir=get_workspace_dir(),
         )
 
         detached = original_detached_option
