@@ -23,7 +23,8 @@ PY2 = sys.version_info[0] == 2
 
 
 def run_before_script(
-    script_file: t.Union[str, pathlib.Path], cwd: t.Optional[pathlib.Path] = None
+    script_file: t.Union[str, pathlib.Path],
+    cwd: t.Optional[pathlib.Path] = None,
 ) -> int:
     """Execute a shell script, wraps :meth:`subprocess.check_call()` in a try/catch."""
     try:
@@ -81,7 +82,7 @@ def oh_my_zsh_auto_title() -> None:
             "in ~/.zshrc or where your zsh profile is stored.\n"
             'Remember the "export" at the beginning!\n\n'
             "Then create a new shell or type:\n\n"
-            "\t$ source ~/.zshrc"
+            "\t$ source ~/.zshrc",
         )
 
 
@@ -153,7 +154,7 @@ def get_pane(window: "Window", current_pane: t.Optional["Pane"] = None) -> "Pane
         if current_pane is not None:
             pane = window.panes.get(pane_id=current_pane.pane_id)
         else:
-            pane = window.attached_pane
+            pane = window.active_pane
     except exc.TmuxpException as e:
         print(e)
 
