@@ -169,11 +169,11 @@ class WorkspaceBuilder:
         self.plugins = plugins
 
         if self.server is not None and self.session_exists(
-            session_name=self.session_config["session_name"]
+            session_name=self.session_config["session_name"],
         ):
             try:
                 session = self.server.sessions.get(
-                    session_name=self.session_config["session_name"]
+                    session_name=self.session_config["session_name"],
                 )
                 assert session is not None
                 self._session = session
@@ -221,7 +221,7 @@ class WorkspaceBuilder:
             if not self.server:
                 raise exc.TmuxpException(
                     "WorkspaceBuilder.build requires server to be passed "
-                    + "on initialization, or pass in session object to here."
+                    + "on initialization, or pass in session object to here.",
                 )
             else:
                 new_session_kwargs = {}
@@ -270,7 +270,7 @@ class WorkspaceBuilder:
                     cwd = self.session_config["start_directory"]
                 run_before_script(self.session_config["before_script"], cwd=cwd)
             except Exception:
-                self.session.kill_session()
+                self.session.kill()
                 raise
 
         if "options" in self.session_config:
@@ -299,10 +299,10 @@ class WorkspaceBuilder:
                 if "layout" in window_config:
                     window.select_layout(window_config["layout"])
 
-                if "focus" in pane_config and pane_config["focus"]:
+                if pane_config.get("focus"):
                     focus_pane = pane
 
-            if "focus" in window_config and window_config["focus"]:
+            if window_config.get("focus"):
                 focus = window
 
             self.config_after_window(window, window_config)
@@ -311,13 +311,15 @@ class WorkspaceBuilder:
                 plugin.after_window_finished(window)
 
             if focus_pane:
-                focus_pane.select_pane()
+                focus_pane.select()
 
         if focus:
-            focus.select_window()
+            focus.select()
 
     def iter_create_windows(
-        self, session: Session, append: bool = False
+        self,
+        session: Session,
+        append: bool = False,
     ) -> t.Iterator[t.Any]:
         """Return :class:`libtmux.Window` iterating through session config dict.
 
@@ -340,17 +342,20 @@ class WorkspaceBuilder:
             that was used to create the window.
         """
         for window_iterator, window_config in enumerate(
-            self.session_config["windows"], start=1
+            self.session_config["windows"],
+            start=1,
         ):
             window_name = window_config.get("window_name", None)
 
             is_first_window_pass = self.first_window_pass(
-                window_iterator, session, append
+                window_iterator,
+                session,
+                append,
             )
 
             w1 = None
             if is_first_window_pass:  # if first window, use window 1
-                w1 = session.attached_window
+                w1 = session.active_window
                 w1.move_window("99")
 
             start_directory = window_config.get("start_directory", None)
@@ -383,7 +388,7 @@ class WorkspaceBuilder:
                     target = "windows"
                 logger.warning(
                     f"Cannot set environment for new {target}. "
-                    "You need tmux 3.0 or newer for this."
+                    "You need tmux 3.0 or newer for this.",
                 )
                 environment = None
 
@@ -398,21 +403,24 @@ class WorkspaceBuilder:
             assert isinstance(window, Window)
 
             if is_first_window_pass:  # if first window, use window 1
-                session.attached_window.kill_window()
+                session.active_window.kill()
 
             if "options" in window_config and isinstance(
-                window_config["options"], dict
+                window_config["options"],
+                dict,
             ):
                 for key, val in window_config["options"].items():
                     window.set_window_option(key, val)
 
-            if "focus" in window_config and window_config["focus"]:
-                window.select_window()
+            if window_config.get("focus"):
+                window.select()
 
             yield window, window_config
 
     def iter_create_panes(
-        self, window: Window, window_config: t.Dict[str, t.Any]
+        self,
+        window: Window,
+        window_config: t.Dict[str, t.Any],
     ) -> t.Iterator[t.Any]:
         """Return :class:`libtmux.Pane` iterating through window config dict.
 
@@ -440,14 +448,16 @@ class WorkspaceBuilder:
         pane = None
 
         for pane_index, pane_config in enumerate(
-            window_config["panes"], start=pane_base_index
+            window_config["panes"],
+            start=pane_base_index,
         ):
             if pane_index == int(pane_base_index):
-                pane = window.attached_pane
+                pane = window.active_pane
             else:
 
                 def get_pane_start_directory(
-                    pane_config: t.Dict[str, str], window_config: t.Dict[str, str]
+                    pane_config: t.Dict[str, str],
+                    window_config: t.Dict[str, str],
                 ) -> t.Optional[str]:
                     if "start_directory" in pane_config:
                         return pane_config["start_directory"]
@@ -457,7 +467,8 @@ class WorkspaceBuilder:
                         return None
 
                 def get_pane_shell(
-                    pane_config: t.Dict[str, str], window_config: t.Dict[str, str]
+                    pane_config: t.Dict[str, str],
+                    window_config: t.Dict[str, str],
                 ) -> t.Optional[str]:
                     if "shell" in pane_config:
                         return pane_config["shell"]
@@ -467,7 +478,8 @@ class WorkspaceBuilder:
                         return None
 
                 environment = pane_config.get(
-                    "environment", window_config.get("environment")
+                    "environment",
+                    window_config.get("environment"),
                 )
                 if environment and has_lt_version("3.0"):
                     # Just issue a warning when the environment comes from the pane
@@ -476,7 +488,7 @@ class WorkspaceBuilder:
                     if pane_config.get("environment"):
                         logger.warning(
                             "Cannot set environment for new panes. "
-                            "You need tmux 3.0 or newer for this."
+                            "You need tmux 3.0 or newer for this.",
                         )
                     environment = None
 
@@ -524,14 +536,16 @@ class WorkspaceBuilder:
                 if sleep_after is not None:
                     time.sleep(sleep_after)
 
-            if "focus" in pane_config and pane_config["focus"]:
+            if pane_config.get("focus"):
                 assert pane.pane_id is not None
                 window.select_pane(pane.pane_id)
 
             yield pane, pane_config
 
     def config_after_window(
-        self, window: Window, window_config: t.Dict[str, t.Any]
+        self,
+        window: Window,
+        window_config: t.Dict[str, t.Any],
     ) -> None:
         """Actions to apply to window after window and pane finished.
 
@@ -547,7 +561,8 @@ class WorkspaceBuilder:
             config section for window
         """
         if "options_after" in window_config and isinstance(
-            window_config["options_after"], dict
+            window_config["options_after"],
+            dict,
         ):
             for key, val in window_config["options_after"].items():
                 window.set_window_option(key, val)
